import QtQuick 1.1
import VPlay 1.0

Loader {
  id: sceneLoader

  // instead of setting the source directly from outside, we use this custom scene property because we can check what scene is requested and add a loading screen if needed
  property string scene

  // if the requested scene is the game scene, we load the loading screen first and then switch to the game scene
  onSceneChanged: {
    if(scene === "GameScene.qml") {
      sceneLoader.source = "LoadingScene.qml"
      delayScene.start()
    } else {
      sceneLoader.source = scene
    }
  }

  onLoaded: {
    // do not forget to call loadItemWithCocos or the item might not be displayed correct!
    loadItemWithCocos(item)
    // set the active scene of the GameWindow to set the focus on the scene
    window.activeScene = sceneLoader.item
    // set the item visible, the Behavior of the SceneBase will make the opacity change smooth
    item.opacity = 1
    // call enterScene of the loaded scene, e.g. to start the game logic
    sceneLoader.item.enterScene()
  }

  Timer {
    id: delayScene
    // fade time of scene opacity change (350ms) plus a little delay to be 100% sure the loading scene is completely loaded and displayed before changing to the game scene
    interval: 400
    running: false
    // after the delay the loading scene is visible, so change the source of the loader to the requested scene
    onTriggered: {
      sceneLoader.source = scene
    }
  }
}

